@@ -1,7 +1,7 @@
 package Log::Message::Structured::Event::ScriptRun;
 use Moose;
 use MooseX::Types::Moose qw/ Str Int /;
-use namespace::autoclean;
+use namespace::clean -except => 'meta';
 
 has script_name => (
     is => 'ro',
@@ -21,8 +21,8 @@ has time => (
 with 'Log::Message::Structured::Stringify::Sprintf' => {
     format_string => q{Script %s run on %s for %ss},
     attributes => [qw/ script_name hostname time /],
-};
-with 'Log::Message::Structured';
+}, 'Log::Message::Structured';
 
 __PACKAGE__->meta->make_immutable;
+1;
 
